Module: OrigenSTIL::Syntax

Defined in:
lib/origen_stil.rb,
lib/origen_stil/syntax/node.rb,
lib/origen_stil/syntax/parser.rb

Overview

Load all files in the lib/origen_stil directory. Note that there is no problem from requiring a file twice (Ruby will ignore the second require), so if you have a file that must be required first, then explicitly require it up above and then let this take care of the rest.

Defined Under Namespace

Classes: Extractor, Node, Parser